pub struct RearmRequest {
pub run: String,
pub id: String,
}Expand description
Naming one webhook registration.
The pair is the registration’s identity: run is the task it follows and
id is the config the receiver registered under it.
Fields
run: Stringid: StringTrait Implementations
Sourceimpl Clone for RearmRequest
impl Clone for RearmRequest
Sourceimpl Debug for RearmRequest
impl Debug for RearmRequest
Sourceimpl<'de> Deserialize<'de> for RearmRequest
impl<'de> Deserialize<'de> for RearmRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RearmRequest
impl JsonSchema for RearmRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RearmRequest
impl RefUnwindSafe for RearmRequest
impl Send for RearmRequest
impl Sync for RearmRequest
impl Unpin for RearmRequest
impl UnsafeUnpin for RearmRequest
impl UnwindSafe for RearmRequest