pub struct ContextPrompt {
pub server: String,
pub name: String,
pub max_input_sensitivity: Sensitivity,
pub output_sensitivity: Sensitivity,
}Fields
server: Stringname: Stringmax_input_sensitivity: Sensitivityoutput_sensitivity: SensitivityTrait Implementations
Sourceimpl Clone for ContextPrompt
impl Clone for ContextPrompt
Sourceimpl Debug for ContextPrompt
impl Debug for ContextPrompt
Sourceimpl<'de> Deserialize<'de> for ContextPrompt
impl<'de> Deserialize<'de> for ContextPrompt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ContextPrompt
impl JsonSchema for ContextPrompt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ContextPrompt
impl PartialEq for ContextPrompt
Sourceimpl Serialize for ContextPrompt
impl Serialize for ContextPrompt
impl StructuralPartialEq for ContextPrompt