pub enum Why {
NotATool,
Sealed,
Erased,
}Expand description
Why a sink is named by its kind alone.
Variants
NotATool
The effect is not a tool call.
Sealed
The arguments are sealed and no key ring was given.
Erased
The arguments’ key was destroyed.